import { append, unorderedArrayDelete, catchError } from "ivi-core";
import { getEventTarget, getNativeEventOptions } from "./utils";
import { SyntheticNativeEvent } from "./synthetic_event";
import { accumulateDispatchTargets } from "./traverse_dom";
import { dispatchEvent } from "./dispatch";
export function createNativeEventSource(flags, name) {
    const source = {
        src: {
            add: () => { ++source.listeners; incDependencies(source); },
            remove: () => { --source.listeners; decDependencies(source); },
        },
        deps: 0,
        listeners: 0,
        flags,
        name,
        before: null,
        after: null,
        dispatch: null,
    };
    const matchEventSource = (h) => h.src === source.src;
    source.dispatch = catchError((ev) => {
        const targets = [];
        if (source.listeners > 0) {
            accumulateDispatchTargets(targets, getEventTarget(ev), matchEventSource);
        }
        if (targets.length || source.before !== null || source.after !== null) {
            const syntheticEvent = new SyntheticNativeEvent(0, getEventTarget(ev), ev.timeStamp, ev);
            dispatchToListeners(source.before, syntheticEvent);
            if (targets.length) {
                dispatchEvent(targets, syntheticEvent, (source.flags & 4 /* Bubbles */) !== 0);
            }
            dispatchToListeners(source.after, syntheticEvent);
            if ((syntheticEvent.flags & 1 /* PreventedDefault */) !== 0) {
                ev.preventDefault();
            }
        }
    });
    return source;
}
export function addBeforeListener(source, cb) {
    source.before = append(source.before, cb);
    incDependencies(source);
}
export function addAfterListener(source, cb) {
    source.after = append(source.after, cb);
    incDependencies(source);
}
export function removeBeforeListener(source, cb) {
    if (source.before !== null) {
        unorderedArrayDelete(source.before, source.before.indexOf(cb));
        decDependencies(source);
    }
}
export function removeAfterListener(source, cb) {
    if (source.after !== null) {
        unorderedArrayDelete(source.after, source.after.indexOf(cb));
        decDependencies(source);
    }
}
function incDependencies(source) {
    if (source.deps++ === 0) {
        document.addEventListener(source.name, source.dispatch, getNativeEventOptions(source.flags));
    }
}
function decDependencies(source) {
    if (--source.deps === 0) {
        document.removeEventListener(source.name, source.dispatch, getNativeEventOptions(source.flags));
    }
}
function dispatchToListeners(listeners, ev) {
    if (listeners !== null) {
        const cbs = listeners.slice();
        for (const cb of cbs) {
            cb(ev);
        }
    }
}
//# sourceMappingURL=native_event_source.js.map