"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * NativeEventSourceFlags.
 */
var NativeEventSourceFlags;
(function (NativeEventSourceFlags) {
    /**
     * Capture flag that indicates that events of this type will be dispatched to the registered listener before
     * being dispatched to any EventTarget beneath it in the DOM tree.
     */
    NativeEventSourceFlags[NativeEventSourceFlags["Capture"] = 1] = "Capture";
    /**
     * Passive flag indicating that the listener will never call `preventDefault()`. If it does, the user agent
     * should ignore it.
     */
    NativeEventSourceFlags[NativeEventSourceFlags["Passive"] = 2] = "Passive";
    /**
     * Bubbles flag indicating that the event is bubbling.
     */
    NativeEventSourceFlags[NativeEventSourceFlags["Bubbles"] = 4] = "Bubbles";
})(NativeEventSourceFlags = exports.NativeEventSourceFlags || (exports.NativeEventSourceFlags = {}));
/**
 * EventHandlerFlags.
 */
var EventHandlerFlags;
(function (EventHandlerFlags) {
    /**
     * Capture flag that indicates that events of this type will be dispatched to the registered listener before
     * being dispatched to any EventTarget beneath it in the DOM tree.
     */
    EventHandlerFlags[EventHandlerFlags["Capture"] = 1] = "Capture";
    /**
     * Bubbles flag indicating that the events of this type will be dispatched to the registered listener in the
     * bubbling phase.
     */
    EventHandlerFlags[EventHandlerFlags["Bubble"] = 2] = "Bubble";
    /**
     * Active flag indicates that Event Handler is activated. Available only in Dev Mode.
     */
    EventHandlerFlags[EventHandlerFlags["Active"] = 4] = "Active";
})(EventHandlerFlags = exports.EventHandlerFlags || (exports.EventHandlerFlags = {}));
/**
 * SyntheticEventFlags.
 */
var SyntheticEventFlags;
(function (SyntheticEventFlags) {
    /**
     * Default behaviour should be prevented.
     */
    SyntheticEventFlags[SyntheticEventFlags["PreventedDefault"] = 1] = "PreventedDefault";
    /**
     * Propagation is stopped.
     */
    SyntheticEventFlags[SyntheticEventFlags["StoppedPropagation"] = 2] = "StoppedPropagation";
    /**
     * Event can bubble up through the DOM.
     */
    SyntheticEventFlags[SyntheticEventFlags["Bubbles"] = 4] = "Bubbles";
    /**
     * Event is cancelable.
     */
    SyntheticEventFlags[SyntheticEventFlags["Cancelable"] = 8] = "Cancelable";
    /**
     * Event was initiated by the browser.
     */
    SyntheticEventFlags[SyntheticEventFlags["IsTrusted"] = 16] = "IsTrusted";
    /**
     * Event at bubbling phase.
     */
    SyntheticEventFlags[SyntheticEventFlags["BubblePhase"] = 32] = "BubblePhase";
})(SyntheticEventFlags = exports.SyntheticEventFlags || (exports.SyntheticEventFlags = {}));
var EventFlags;
(function (EventFlags) {
    EventFlags[EventFlags["PreventDefault"] = 1] = "PreventDefault";
    EventFlags[EventFlags["StopPropagation"] = 2] = "StopPropagation";
})(EventFlags = exports.EventFlags || (exports.EventFlags = {}));
/**
 * Prevents default behaviour for an event.
 */
exports.PREVENT_DEFAULT = 1 /* PreventedDefault */;
/**
 * Stops event propagation.
 */
exports.STOP_PROPAGATION = 2 /* StoppedPropagation */;
//# sourceMappingURL=flags.js.map