"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
exports.getEventTarget = utils_1.getEventTarget;
exports.getNativeEventOptions = utils_1.getNativeEventOptions;
exports.EVENT_CAPTURE_PASSIVE_OPTIONS = utils_1.EVENT_CAPTURE_PASSIVE_OPTIONS;
exports.EVENT_CAPTURE_ACTIVE_OPTIONS = utils_1.EVENT_CAPTURE_ACTIVE_OPTIONS;
exports.EVENT_PASSIVE_OPTIONS = utils_1.EVENT_PASSIVE_OPTIONS;
exports.EVENT_ACTIVE_OPTIONS = utils_1.EVENT_ACTIVE_OPTIONS;
var flags_1 = require("./flags");
exports.NativeEventSourceFlags = flags_1.NativeEventSourceFlags;
exports.EventHandlerFlags = flags_1.EventHandlerFlags;
exports.SyntheticEventFlags = flags_1.SyntheticEventFlags;
exports.EventFlags = flags_1.EventFlags;
exports.PREVENT_DEFAULT = flags_1.PREVENT_DEFAULT;
exports.STOP_PROPAGATION = flags_1.STOP_PROPAGATION;
var traverse_dom_1 = require("./traverse_dom");
exports.accumulateDispatchTargets = traverse_dom_1.accumulateDispatchTargets;
exports.accumulateDispatchTargetsFromElement = traverse_dom_1.accumulateDispatchTargetsFromElement;
var dispatch_1 = require("./dispatch");
exports.dispatchEvent = dispatch_1.dispatchEvent;
var synthetic_event_1 = require("./synthetic_event");
exports.SyntheticEvent = synthetic_event_1.SyntheticEvent;
exports.SyntheticNativeEvent = synthetic_event_1.SyntheticNativeEvent;
var native_event_source_1 = require("./native_event_source");
exports.createNativeEventSource = native_event_source_1.createNativeEventSource;
exports.addBeforeListener = native_event_source_1.addBeforeListener;
exports.addAfterListener = native_event_source_1.addAfterListener;
exports.removeBeforeListener = native_event_source_1.removeBeforeListener;
exports.removeAfterListener = native_event_source_1.removeAfterListener;
var sync_events_1 = require("./sync_events");
exports.syncEvents = sync_events_1.syncEvents;
exports.attachEvents = sync_events_1.attachEvents;
exports.detachEvents = sync_events_1.detachEvents;
var events_1 = require("./events");
exports.EVENT_SOURCE_ABORT = events_1.EVENT_SOURCE_ABORT;
exports.EVENT_SOURCE_ACTIVATE = events_1.EVENT_SOURCE_ACTIVATE;
exports.EVENT_SOURCE_ARIA_REQUEST = events_1.EVENT_SOURCE_ARIA_REQUEST;
exports.EVENT_SOURCE_BEFORE_ACTIVATE = events_1.EVENT_SOURCE_BEFORE_ACTIVATE;
exports.EVENT_SOURCE_BEFORE_COPY = events_1.EVENT_SOURCE_BEFORE_COPY;
exports.EVENT_SOURCE_BEFORE_CUT = events_1.EVENT_SOURCE_BEFORE_CUT;
exports.EVENT_SOURCE_BEFORE_DEACTIVATE = events_1.EVENT_SOURCE_BEFORE_DEACTIVATE;
exports.EVENT_SOURCE_BEFORE_PASTE = events_1.EVENT_SOURCE_BEFORE_PASTE;
exports.EVENT_SOURCE_BLUR = events_1.EVENT_SOURCE_BLUR;
exports.EVENT_SOURCE_CAN_PLAY = events_1.EVENT_SOURCE_CAN_PLAY;
exports.EVENT_SOURCE_CAN_PLAYTHROUGH = events_1.EVENT_SOURCE_CAN_PLAYTHROUGH;
exports.EVENT_SOURCE_CHANGE = events_1.EVENT_SOURCE_CHANGE;
exports.EVENT_SOURCE_CLICK = events_1.EVENT_SOURCE_CLICK;
exports.EVENT_SOURCE_CONTEXT_MENU = events_1.EVENT_SOURCE_CONTEXT_MENU;
exports.EVENT_SOURCE_COPY = events_1.EVENT_SOURCE_COPY;
exports.EVENT_SOURCE_CUE_CHANGE = events_1.EVENT_SOURCE_CUE_CHANGE;
exports.EVENT_SOURCE_CUT = events_1.EVENT_SOURCE_CUT;
exports.EVENT_SOURCE_DOUBLE_CLICK = events_1.EVENT_SOURCE_DOUBLE_CLICK;
exports.EVENT_SOURCE_DEACTIVATE = events_1.EVENT_SOURCE_DEACTIVATE;
exports.EVENT_SOURCE_DRAG = events_1.EVENT_SOURCE_DRAG;
exports.EVENT_SOURCE_DRAG_END = events_1.EVENT_SOURCE_DRAG_END;
exports.EVENT_SOURCE_DRAG_ENTER = events_1.EVENT_SOURCE_DRAG_ENTER;
exports.EVENT_SOURCE_DRAG_LEAVE = events_1.EVENT_SOURCE_DRAG_LEAVE;
exports.EVENT_SOURCE_DRAG_OVER = events_1.EVENT_SOURCE_DRAG_OVER;
exports.EVENT_SOURCE_DRAG_START = events_1.EVENT_SOURCE_DRAG_START;
exports.EVENT_SOURCE_DROP = events_1.EVENT_SOURCE_DROP;
exports.EVENT_SOURCE_DURATION_CHANGE = events_1.EVENT_SOURCE_DURATION_CHANGE;
exports.EVENT_SOURCE_EMPTIED = events_1.EVENT_SOURCE_EMPTIED;
exports.EVENT_SOURCE_ENCRYPTED = events_1.EVENT_SOURCE_ENCRYPTED;
exports.EVENT_SOURCE_ENDED = events_1.EVENT_SOURCE_ENDED;
exports.EVENT_SOURCE_ERROR = events_1.EVENT_SOURCE_ERROR;
exports.EVENT_SOURCE_FOCUS = events_1.EVENT_SOURCE_FOCUS;
exports.EVENT_SOURCE_GOT_POINTER_CAPTURE = events_1.EVENT_SOURCE_GOT_POINTER_CAPTURE;
exports.EVENT_SOURCE_INPUT = events_1.EVENT_SOURCE_INPUT;
exports.EVENT_SOURCE_INVALID = events_1.EVENT_SOURCE_INVALID;
exports.EVENT_SOURCE_KEY_DOWN = events_1.EVENT_SOURCE_KEY_DOWN;
exports.EVENT_SOURCE_KEY_PRESS = events_1.EVENT_SOURCE_KEY_PRESS;
exports.EVENT_SOURCE_KEY_UP = events_1.EVENT_SOURCE_KEY_UP;
exports.EVENT_SOURCE_LOAD = events_1.EVENT_SOURCE_LOAD;
exports.EVENT_SOURCE_LOADED_DATA = events_1.EVENT_SOURCE_LOADED_DATA;
exports.EVENT_SOURCE_LOADED_METADATA = events_1.EVENT_SOURCE_LOADED_METADATA;
exports.EVENT_SOURCE_LOAD_START = events_1.EVENT_SOURCE_LOAD_START;
exports.EVENT_SOURCE_LOST_POINTER_CAPTURE = events_1.EVENT_SOURCE_LOST_POINTER_CAPTURE;
exports.EVENT_SOURCE_MOUSE_DOWN = events_1.EVENT_SOURCE_MOUSE_DOWN;
exports.EVENT_SOURCE_MOUSE_ENTER = events_1.EVENT_SOURCE_MOUSE_ENTER;
exports.EVENT_SOURCE_MOUSE_LEAVE = events_1.EVENT_SOURCE_MOUSE_LEAVE;
exports.EVENT_SOURCE_MOUSE_MOVE = events_1.EVENT_SOURCE_MOUSE_MOVE;
exports.EVENT_SOURCE_MOUSE_OUT = events_1.EVENT_SOURCE_MOUSE_OUT;
exports.EVENT_SOURCE_MOUSE_OVER = events_1.EVENT_SOURCE_MOUSE_OVER;
exports.EVENT_SOURCE_MOUSE_UP = events_1.EVENT_SOURCE_MOUSE_UP;
exports.EVENT_SOURCE_PASTE = events_1.EVENT_SOURCE_PASTE;
exports.EVENT_SOURCE_PAUSE = events_1.EVENT_SOURCE_PAUSE;
exports.EVENT_SOURCE_PLAY = events_1.EVENT_SOURCE_PLAY;
exports.EVENT_SOURCE_PLAYING = events_1.EVENT_SOURCE_PLAYING;
exports.EVENT_SOURCE_POINTER_CANCEL = events_1.EVENT_SOURCE_POINTER_CANCEL;
exports.EVENT_SOURCE_POINTER_DOWN = events_1.EVENT_SOURCE_POINTER_DOWN;
exports.EVENT_SOURCE_POINTER_ENTER = events_1.EVENT_SOURCE_POINTER_ENTER;
exports.EVENT_SOURCE_POINTER_LEAVE = events_1.EVENT_SOURCE_POINTER_LEAVE;
exports.EVENT_SOURCE_POINTER_MOVE = events_1.EVENT_SOURCE_POINTER_MOVE;
exports.EVENT_SOURCE_POINTER_OUT = events_1.EVENT_SOURCE_POINTER_OUT;
exports.EVENT_SOURCE_POINTER_OVER = events_1.EVENT_SOURCE_POINTER_OVER;
exports.EVENT_SOURCE_POINTER_UP = events_1.EVENT_SOURCE_POINTER_UP;
exports.EVENT_SOURCE_PROGRESS = events_1.EVENT_SOURCE_PROGRESS;
exports.EVENT_SOURCE_RATE_CHANGE = events_1.EVENT_SOURCE_RATE_CHANGE;
exports.EVENT_SOURCE_RESET = events_1.EVENT_SOURCE_RESET;
exports.EVENT_SOURCE_SCROLL = events_1.EVENT_SOURCE_SCROLL;
exports.EVENT_SOURCE_SEEKED = events_1.EVENT_SOURCE_SEEKED;
exports.EVENT_SOURCE_SEEKING = events_1.EVENT_SOURCE_SEEKING;
exports.EVENT_SOURCE_SELECT = events_1.EVENT_SOURCE_SELECT;
exports.EVENT_SOURCE_SELECT_START = events_1.EVENT_SOURCE_SELECT_START;
exports.EVENT_SOURCE_STALLED = events_1.EVENT_SOURCE_STALLED;
exports.EVENT_SOURCE_SUBMIT = events_1.EVENT_SOURCE_SUBMIT;
exports.EVENT_SOURCE_SUSPEND = events_1.EVENT_SOURCE_SUSPEND;
exports.EVENT_SOURCE_TIME_UPDATE = events_1.EVENT_SOURCE_TIME_UPDATE;
exports.EVENT_SOURCE_TOUCH_CANCEL = events_1.EVENT_SOURCE_TOUCH_CANCEL;
exports.EVENT_SOURCE_TOUCH_END = events_1.EVENT_SOURCE_TOUCH_END;
exports.EVENT_SOURCE_TOUCH_MOVE = events_1.EVENT_SOURCE_TOUCH_MOVE;
exports.EVENT_SOURCE_TOUCH_START = events_1.EVENT_SOURCE_TOUCH_START;
exports.EVENT_SOURCE_UNLOAD = events_1.EVENT_SOURCE_UNLOAD;
exports.EVENT_SOURCE_VOLUME_CHANGE = events_1.EVENT_SOURCE_VOLUME_CHANGE;
exports.EVENT_SOURCE_WAITING = events_1.EVENT_SOURCE_WAITING;
exports.EVENT_SOURCE_WHEEL = events_1.EVENT_SOURCE_WHEEL;
exports.EVENT_SOURCE_ACTIVE_TOUCH_END = events_1.EVENT_SOURCE_ACTIVE_TOUCH_END;
exports.EVENT_SOURCE_ACTIVE_TOUCH_MOVE = events_1.EVENT_SOURCE_ACTIVE_TOUCH_MOVE;
exports.EVENT_SOURCE_ACTIVE_TOUCH_START = events_1.EVENT_SOURCE_ACTIVE_TOUCH_START;
exports.EVENT_SOURCE_ACTIVE_WHEEL = events_1.EVENT_SOURCE_ACTIVE_WHEEL;
exports.createEventHandler = events_1.createEventHandler;
exports.onAbort = events_1.onAbort;
exports.onActivate = events_1.onActivate;
exports.onAriaRequest = events_1.onAriaRequest;
exports.onBeforeActivate = events_1.onBeforeActivate;
exports.onBeforeCopy = events_1.onBeforeCopy;
exports.onBeforeCut = events_1.onBeforeCut;
exports.onBeforeDeactivate = events_1.onBeforeDeactivate;
exports.onBeforePaste = events_1.onBeforePaste;
exports.onBlur = events_1.onBlur;
exports.onCanPlay = events_1.onCanPlay;
exports.onCanPlaythrough = events_1.onCanPlaythrough;
exports.onChange = events_1.onChange;
exports.onClick = events_1.onClick;
exports.onContextMenu = events_1.onContextMenu;
exports.onCopy = events_1.onCopy;
exports.onCueChange = events_1.onCueChange;
exports.onCut = events_1.onCut;
exports.onDoubleClick = events_1.onDoubleClick;
exports.onDeactivate = events_1.onDeactivate;
exports.onDrag = events_1.onDrag;
exports.onDragEnd = events_1.onDragEnd;
exports.onDragEnter = events_1.onDragEnter;
exports.onDragLeave = events_1.onDragLeave;
exports.onDragOver = events_1.onDragOver;
exports.onDragStart = events_1.onDragStart;
exports.onDrop = events_1.onDrop;
exports.onDurationChange = events_1.onDurationChange;
exports.onEmptied = events_1.onEmptied;
exports.onEncrypted = events_1.onEncrypted;
exports.onEnded = events_1.onEnded;
exports.onError = events_1.onError;
exports.onFocus = events_1.onFocus;
exports.onGotPointerCapture = events_1.onGotPointerCapture;
exports.onInput = events_1.onInput;
exports.onInvalid = events_1.onInvalid;
exports.onKeyDown = events_1.onKeyDown;
exports.onKeyPress = events_1.onKeyPress;
exports.onKeyUp = events_1.onKeyUp;
exports.onLoad = events_1.onLoad;
exports.onLoadedData = events_1.onLoadedData;
exports.onLoadedMetadata = events_1.onLoadedMetadata;
exports.onLoadStart = events_1.onLoadStart;
exports.onLostPointerCapture = events_1.onLostPointerCapture;
exports.onMouseDown = events_1.onMouseDown;
exports.onMouseEnter = events_1.onMouseEnter;
exports.onMouseLeave = events_1.onMouseLeave;
exports.onMouseMove = events_1.onMouseMove;
exports.onMouseOut = events_1.onMouseOut;
exports.onMouseOver = events_1.onMouseOver;
exports.onMouseUp = events_1.onMouseUp;
exports.onPaste = events_1.onPaste;
exports.onPause = events_1.onPause;
exports.onPlay = events_1.onPlay;
exports.onPlaying = events_1.onPlaying;
exports.onPointerCancel = events_1.onPointerCancel;
exports.onPointerDown = events_1.onPointerDown;
exports.onPointerEnter = events_1.onPointerEnter;
exports.onPointerLeave = events_1.onPointerLeave;
exports.onPointerMove = events_1.onPointerMove;
exports.onPointerOut = events_1.onPointerOut;
exports.onPointerOver = events_1.onPointerOver;
exports.onPointerUp = events_1.onPointerUp;
exports.onProgress = events_1.onProgress;
exports.onRateChange = events_1.onRateChange;
exports.onReset = events_1.onReset;
exports.onScroll = events_1.onScroll;
exports.onSeeked = events_1.onSeeked;
exports.onSeeking = events_1.onSeeking;
exports.onSelect = events_1.onSelect;
exports.onSelectStart = events_1.onSelectStart;
exports.onStalled = events_1.onStalled;
exports.onSubmit = events_1.onSubmit;
exports.onSuspend = events_1.onSuspend;
exports.onTimeUpdate = events_1.onTimeUpdate;
exports.onTouchCancel = events_1.onTouchCancel;
exports.onTouchEnd = events_1.onTouchEnd;
exports.onTouchMove = events_1.onTouchMove;
exports.onTouchStart = events_1.onTouchStart;
exports.onUnload = events_1.onUnload;
exports.onVolumeChange = events_1.onVolumeChange;
exports.onWaiting = events_1.onWaiting;
exports.onWheel = events_1.onWheel;
exports.onActiveTouchEnd = events_1.onActiveTouchEnd;
exports.onActiveTouchMove = events_1.onActiveTouchMove;
exports.onActiveTouchStart = events_1.onActiveTouchStart;
exports.onActiveWheel = events_1.onActiveWheel;
//# sourceMappingURL=index.js.map