"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ivi_core_1 = require("ivi-core");
const utils_1 = require("./utils");
const synthetic_event_1 = require("./synthetic_event");
const traverse_dom_1 = require("./traverse_dom");
const dispatch_1 = require("./dispatch");
function createNativeEventSource(flags, name) {
    const source = {
        src: {
            add: () => { ++source.listeners; incDependencies(source); },
            remove: () => { --source.listeners; decDependencies(source); },
        },
        deps: 0,
        listeners: 0,
        flags,
        name,
        before: null,
        after: null,
        dispatch: null,
    };
    const matchEventSource = (h) => h.src === source.src;
    source.dispatch = ivi_core_1.catchError((ev) => {
        const targets = [];
        if (source.listeners > 0) {
            traverse_dom_1.accumulateDispatchTargets(targets, utils_1.getEventTarget(ev), matchEventSource);
        }
        if (targets.length || source.before !== null || source.after !== null) {
            const syntheticEvent = new synthetic_event_1.SyntheticNativeEvent(0, utils_1.getEventTarget(ev), ev.timeStamp, ev);
            dispatchToListeners(source.before, syntheticEvent);
            if (targets.length) {
                dispatch_1.dispatchEvent(targets, syntheticEvent, (source.flags & 4 /* Bubbles */) !== 0);
            }
            dispatchToListeners(source.after, syntheticEvent);
            if ((syntheticEvent.flags & 1 /* PreventedDefault */) !== 0) {
                ev.preventDefault();
            }
        }
    });
    return source;
}
exports.createNativeEventSource = createNativeEventSource;
function addBeforeListener(source, cb) {
    source.before = ivi_core_1.append(source.before, cb);
    incDependencies(source);
}
exports.addBeforeListener = addBeforeListener;
function addAfterListener(source, cb) {
    source.after = ivi_core_1.append(source.after, cb);
    incDependencies(source);
}
exports.addAfterListener = addAfterListener;
function removeBeforeListener(source, cb) {
    if (source.before !== null) {
        ivi_core_1.unorderedArrayDelete(source.before, source.before.indexOf(cb));
        decDependencies(source);
    }
}
exports.removeBeforeListener = removeBeforeListener;
function removeAfterListener(source, cb) {
    if (source.after !== null) {
        ivi_core_1.unorderedArrayDelete(source.after, source.after.indexOf(cb));
        decDependencies(source);
    }
}
exports.removeAfterListener = removeAfterListener;
function incDependencies(source) {
    if (source.deps++ === 0) {
        document.addEventListener(source.name, source.dispatch, utils_1.getNativeEventOptions(source.flags));
    }
}
function decDependencies(source) {
    if (--source.deps === 0) {
        document.removeEventListener(source.name, source.dispatch, utils_1.getNativeEventOptions(source.flags));
    }
}
function dispatchToListeners(listeners, ev) {
    if (listeners !== null) {
        const cbs = listeners.slice();
        for (const cb of cbs) {
            cb(ev);
        }
    }
}
//# sourceMappingURL=native_event_source.js.map