"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * registerEventHandler is a shortcut for Event Handler registration.
 *
 * @param handler Event Handler.
 */
function registerEventHandler(handler) {
    if (DEBUG) {
        handler.flags |= 4 /* Active */;
    }
    handler.src.add(handler);
}
/**
 * unregisterEventHandler is a shortcut for Event Handler unregistration.
 *
 * @param handler Event Handler.
 */
function unregisterEventHandler(handler) {
    if (DEBUG) {
        handler.flags &= ~4 /* Active */;
    }
    handler.src.remove(handler);
}
/**
 * syncEvents syncs event handlers and invokes EventSource callbacks when event handler is attached or detached.
 *
 * @param a Old event handlers.
 * @param b New event handlers.
 */
function syncEvents(a, b) {
    let i;
    let h1;
    let h2;
    if (a === null) {
        attachEvents(b);
    }
    else if (b === null) {
        detachEvents(a);
    }
    else {
        if (a instanceof Array) {
            if (b instanceof Array) {
                i = 0;
                while (i < a.length && i < b.length) {
                    h1 = a[i];
                    h2 = b[i++];
                    if (h1 !== h2) {
                        if (h2 !== null) {
                            registerEventHandler(h2);
                        }
                        if (h1 !== null) {
                            unregisterEventHandler(h1);
                        }
                    }
                }
                while (i < b.length) {
                    h1 = b[i++];
                    if (h1 !== null) {
                        registerEventHandler(h1);
                    }
                }
                while (i < a.length) {
                    h1 = a[i++];
                    if (h1 !== null) {
                        unregisterEventHandler(h1);
                    }
                }
            }
            else {
                registerEventHandler(b);
                for (i = 0; i < a.length; ++i) {
                    h1 = a[i];
                    if (h1 !== null) {
                        unregisterEventHandler(h1);
                    }
                }
            }
        }
        else {
            attachEvents(b);
            unregisterEventHandler(a);
        }
    }
}
exports.syncEvents = syncEvents;
/**
 * attachEvents attaches event handlers and invokes EventSource callbacks.
 *
 * @param events Event handlers.
 */
function attachEvents(events) {
    if (events instanceof Array) {
        for (let i = 0; i < events.length; ++i) {
            const h = events[i];
            if (h !== null) {
                registerEventHandler(h);
            }
        }
    }
    else {
        registerEventHandler(events);
    }
}
exports.attachEvents = attachEvents;
/**
 * detachEvents detaches events handles and invokes EventSource callbacks.
 *
 * @param events Event handlers.
 */
function detachEvents(events) {
    if (events instanceof Array) {
        for (let i = 0; i < events.length; ++i) {
            const h = events[i];
            if (h !== null) {
                unregisterEventHandler(h);
            }
        }
    }
    else {
        unregisterEventHandler(events);
    }
}
exports.detachEvents = detachEvents;
//# sourceMappingURL=sync_events.js.map