"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * accumulateDispatchTargetsFromElement accumulates matching Event Handlers in `result` array from the `target` Element.
 *
 * @param result Accumulated Dispatch Targets.
 * @param target Target Element.
 * @param match Matching function.
 */
function accumulateDispatchTargetsFromElement(result, target, match) {
    const events = target._ev;
    if (events) {
        let handlers;
        if (Array.isArray(events)) {
            let count = 0;
            for (const h of events) {
                if (h !== null && match(h) === true) {
                    if (count === 0) {
                        handlers = h;
                    }
                    else if (count === 1) {
                        handlers = [handlers, h];
                    }
                    else {
                        handlers.push(h);
                    }
                    ++count;
                }
            }
        }
        else {
            if (match(events) === true) {
                handlers = events;
            }
        }
        if (handlers !== void 0) {
            result.push({ target, handlers });
        }
    }
}
exports.accumulateDispatchTargetsFromElement = accumulateDispatchTargetsFromElement;
/**
 * accumulateDispatchTargets traverses the DOM tree from the `target` Element to the document top and accumulates
 * matching Event Handlers in `result` array.
 *
 * @param result Accumulated Dispatch Targets.
 * @param target Target DOM Element.
 * @param match Matching function.
 */
function accumulateDispatchTargets(result, target, match) {
    while (target !== null) {
        accumulateDispatchTargetsFromElement(result, target, match);
        target = target.parentElement;
    }
}
exports.accumulateDispatchTargets = accumulateDispatchTargets;
//# sourceMappingURL=traverse_dom.js.map