/**
 * accumulateDispatchTargetsFromElement accumulates matching Event Handlers in `result` array from the `target` Element.
 *
 * @param result Accumulated Dispatch Targets.
 * @param target Target Element.
 * @param match Matching function.
 */
export function accumulateDispatchTargetsFromElement(result, target, match) {
    var events = target._ev;
    if (events) {
        var handlers = void 0;
        if (Array.isArray(events)) {
            var count = 0;
            for (var _i = 0, events_1 = events; _i < events_1.length; _i++) {
                var h = events_1[_i];
                if (h !== null && match(h) === true) {
                    if (count === 0) {
                        handlers = h;
                    }
                    else if (count === 1) {
                        handlers = [handlers, h];
                    }
                    else {
                        handlers.push(h);
                    }
                    ++count;
                }
            }
        }
        else {
            if (match(events) === true) {
                handlers = events;
            }
        }
        if (handlers !== void 0) {
            result.push({ target: target, handlers: handlers });
        }
    }
}
/**
 * accumulateDispatchTargets traverses the DOM tree from the `target` Element to the document top and accumulates
 * matching Event Handlers in `result` array.
 *
 * @param result Accumulated Dispatch Targets.
 * @param target Target DOM Element.
 * @param match Matching function.
 */
export function accumulateDispatchTargets(result, target, match) {
    while (target !== null) {
        accumulateDispatchTargetsFromElement(result, target, match);
        target = target.parentElement;
    }
}
//# sourceMappingURL=traverse_dom.js.map