import { EventFlags } from "./flags";
import { EventHandler } from "./event_handler";
import { SyntheticEvent } from "./synthetic_event";
/**
 * DispatchTarget.
 */
export interface DispatchTarget {
    /**
     * Target.
     */
    target: any;
    /**
     * Matched Event Handlers.
     */
    handlers: EventHandler | EventHandler[];
}
/**
 * dispatchEvent dispatches event to the list of dispatch targets.
 *
 * Simplified version of w3 Events flow algorithm. This algorithm doesn't include target phase, only capture and
 * bubbling phases. We don't care too much about w3 events compatibility, and there aren't any use cases that require
 * target phase.
 *
 * https://www.w3.org/TR/DOM-Level-3-Events/#event-flow
 *
 * @param targets Dispatch targets.
 * @param event Event to dispatch.
 * @param bubble Use bubbling phase.
 * @param dispatch Dispatch callback.
 */
export declare function dispatchEvent(targets: DispatchTarget[], event: SyntheticEvent, bubble: boolean, dispatch?: (h: EventHandler, ev: SyntheticEvent) => EventFlags | void): void;
