/**
 * Event Handlers.
 *
 * Optimizing compilers should inline all this functions and completely remove unused code.
 */
import { EventFlags } from "./flags";
import { EventHandler } from "./event_handler";
import { EventSource } from "./event_source";
import { NativeEventSource } from "./native_event_source";
import { SyntheticNativeEvent } from "./synthetic_event";
export declare const EVENT_SOURCE_ABORT: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_ACTIVATE: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_ARIA_REQUEST: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_BEFORE_ACTIVATE: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_BEFORE_COPY: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_BEFORE_CUT: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_BEFORE_DEACTIVATE: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_BEFORE_PASTE: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_BLUR: NativeEventSource<FocusEvent>;
export declare const EVENT_SOURCE_CAN_PLAY: NativeEventSource<Event>;
export declare const EVENT_SOURCE_CAN_PLAYTHROUGH: NativeEventSource<Event>;
export declare const EVENT_SOURCE_CHANGE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_CLICK: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_CONTEXT_MENU: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_COPY: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_CUE_CHANGE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_CUT: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_DOUBLE_CLICK: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_DEACTIVATE: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_DRAG: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DRAG_END: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DRAG_ENTER: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DRAG_LEAVE: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DRAG_OVER: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DRAG_START: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DROP: NativeEventSource<DragEvent>;
export declare const EVENT_SOURCE_DURATION_CHANGE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_EMPTIED: NativeEventSource<Event>;
export declare const EVENT_SOURCE_ENCRYPTED: NativeEventSource<MediaEncryptedEvent>;
export declare const EVENT_SOURCE_ENDED: NativeEventSource<MediaStreamErrorEvent>;
export declare const EVENT_SOURCE_ERROR: NativeEventSource<ErrorEvent>;
export declare const EVENT_SOURCE_FOCUS: NativeEventSource<FocusEvent>;
export declare const EVENT_SOURCE_GOT_POINTER_CAPTURE: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_INPUT: NativeEventSource<Event>;
export declare const EVENT_SOURCE_INVALID: NativeEventSource<Event>;
export declare const EVENT_SOURCE_KEY_DOWN: NativeEventSource<KeyboardEvent>;
export declare const EVENT_SOURCE_KEY_PRESS: NativeEventSource<KeyboardEvent>;
export declare const EVENT_SOURCE_KEY_UP: NativeEventSource<KeyboardEvent>;
export declare const EVENT_SOURCE_LOAD: NativeEventSource<Event>;
export declare const EVENT_SOURCE_LOADED_DATA: NativeEventSource<Event>;
export declare const EVENT_SOURCE_LOADED_METADATA: NativeEventSource<Event>;
export declare const EVENT_SOURCE_LOAD_START: NativeEventSource<Event>;
export declare const EVENT_SOURCE_LOST_POINTER_CAPTURE: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_MOUSE_DOWN: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_ENTER: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_LEAVE: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_MOVE: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_OUT: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_OVER: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_MOUSE_UP: NativeEventSource<MouseEvent>;
export declare const EVENT_SOURCE_PASTE: NativeEventSource<ClipboardEvent>;
export declare const EVENT_SOURCE_PAUSE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_PLAY: NativeEventSource<Event>;
export declare const EVENT_SOURCE_PLAYING: NativeEventSource<Event>;
export declare const EVENT_SOURCE_POINTER_CANCEL: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_DOWN: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_ENTER: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_LEAVE: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_MOVE: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_OUT: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_OVER: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_POINTER_UP: NativeEventSource<PointerEvent>;
export declare const EVENT_SOURCE_PROGRESS: NativeEventSource<ProgressEvent>;
export declare const EVENT_SOURCE_RATE_CHANGE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_RESET: NativeEventSource<Event>;
export declare const EVENT_SOURCE_SCROLL: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_SEEKED: NativeEventSource<Event>;
export declare const EVENT_SOURCE_SEEKING: NativeEventSource<Event>;
export declare const EVENT_SOURCE_SELECT: NativeEventSource<UIEvent>;
export declare const EVENT_SOURCE_SELECT_START: NativeEventSource<Event>;
export declare const EVENT_SOURCE_STALLED: NativeEventSource<Event>;
export declare const EVENT_SOURCE_SUBMIT: NativeEventSource<Event>;
export declare const EVENT_SOURCE_SUSPEND: NativeEventSource<Event>;
export declare const EVENT_SOURCE_TIME_UPDATE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_TOUCH_CANCEL: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_TOUCH_END: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_TOUCH_MOVE: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_TOUCH_START: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_UNLOAD: NativeEventSource<Event>;
export declare const EVENT_SOURCE_VOLUME_CHANGE: NativeEventSource<Event>;
export declare const EVENT_SOURCE_WAITING: NativeEventSource<Event>;
export declare const EVENT_SOURCE_WHEEL: NativeEventSource<WheelEvent>;
export declare const EVENT_SOURCE_ACTIVE_TOUCH_END: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_ACTIVE_TOUCH_MOVE: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_ACTIVE_TOUCH_START: NativeEventSource<TouchEvent>;
export declare const EVENT_SOURCE_ACTIVE_WHEEL: NativeEventSource<WheelEvent>;
/**
 * Helper function that creates event handlers.
 *
 * @param src - Event source
 * @param handler - Event Handler function
 * @param capture - Capture mode
 * @returns EventHandler instance
 */
export declare function createEventHandler<E extends SyntheticNativeEvent<any>>(src: EventSource, handler: (ev: E) => EventFlags | void, capture?: boolean): EventHandler<E>;
export declare function onAbort(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onActivate(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onAriaRequest(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onBeforeActivate(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onBeforeCopy(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onBeforeCut(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onBeforeDeactivate(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onBeforePaste(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onBlur(handler: (ev: SyntheticNativeEvent<FocusEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<FocusEvent>>;
export declare function onCanPlay(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onCanPlaythrough(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onChange(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onClick(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onContextMenu(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onCopy(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onCueChange(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onCut(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onDoubleClick(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onDeactivate(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onDrag(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDragEnd(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDragEnter(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDragLeave(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDragOver(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDragStart(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDrop(handler: (ev: SyntheticNativeEvent<DragEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<DragEvent>>;
export declare function onDurationChange(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onEmptied(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onEncrypted(handler: (ev: SyntheticNativeEvent<MediaEncryptedEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MediaEncryptedEvent>>;
export declare function onEnded(handler: (ev: SyntheticNativeEvent<MediaStreamErrorEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MediaStreamErrorEvent>>;
export declare function onError(handler: (ev: SyntheticNativeEvent<ErrorEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ErrorEvent>>;
export declare function onFocus(handler: (ev: SyntheticNativeEvent<FocusEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<FocusEvent>>;
export declare function onGotPointerCapture(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onInput(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onInvalid(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onKeyDown(handler: (ev: SyntheticNativeEvent<KeyboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<KeyboardEvent>>;
export declare function onKeyPress(handler: (ev: SyntheticNativeEvent<KeyboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<KeyboardEvent>>;
export declare function onKeyUp(handler: (ev: SyntheticNativeEvent<KeyboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<KeyboardEvent>>;
export declare function onLoad(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onLoadedData(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onLoadedMetadata(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onLoadStart(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onLostPointerCapture(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onMouseDown(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseEnter(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseLeave(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseMove(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseOut(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseOver(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onMouseUp(handler: (ev: SyntheticNativeEvent<MouseEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<MouseEvent>>;
export declare function onPaste(handler: (ev: SyntheticNativeEvent<ClipboardEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ClipboardEvent>>;
export declare function onPause(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onPlay(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onPlaying(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onPointerCancel(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerDown(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerEnter(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerLeave(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerMove(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerOut(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerOver(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onPointerUp(handler: (ev: SyntheticNativeEvent<PointerEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<PointerEvent>>;
export declare function onProgress(handler: (ev: SyntheticNativeEvent<ProgressEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<ProgressEvent>>;
export declare function onRateChange(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onReset(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onScroll(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onSeeked(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onSeeking(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onSelect(handler: (ev: SyntheticNativeEvent<UIEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<UIEvent>>;
export declare function onSelectStart(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onStalled(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onSubmit(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onSuspend(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onTimeUpdate(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onTouchCancel(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onTouchEnd(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onTouchMove(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onTouchStart(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onUnload(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onVolumeChange(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onWaiting(handler: (ev: SyntheticNativeEvent<Event>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<Event>>;
export declare function onWheel(handler: (ev: SyntheticNativeEvent<WheelEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<WheelEvent>>;
export declare function onActiveTouchEnd(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onActiveTouchMove(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onActiveTouchStart(handler: (ev: SyntheticNativeEvent<TouchEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<TouchEvent>>;
export declare function onActiveWheel(handler: (ev: SyntheticNativeEvent<WheelEvent>) => EventFlags | void, capture?: boolean): EventHandler<SyntheticNativeEvent<WheelEvent>>;
