/**
 * NativeEventSourceFlags.
 */
export declare const enum NativeEventSourceFlags {
    /**
     * Capture flag that indicates that events of this type will be dispatched to the registered listener before
     * being dispatched to any EventTarget beneath it in the DOM tree.
     */
    Capture = 1,
    /**
     * Passive flag indicating that the listener will never call `preventDefault()`. If it does, the user agent
     * should ignore it.
     */
    Passive = 2,
    /**
     * Bubbles flag indicating that the event is bubbling.
     */
    Bubbles = 4,
}
/**
 * EventHandlerFlags.
 */
export declare const enum EventHandlerFlags {
    /**
     * Capture flag that indicates that events of this type will be dispatched to the registered listener before
     * being dispatched to any EventTarget beneath it in the DOM tree.
     */
    Capture = 1,
    /**
     * Bubbles flag indicating that the events of this type will be dispatched to the registered listener in the
     * bubbling phase.
     */
    Bubble = 2,
    /**
     * Active flag indicates that Event Handler is activated. Available only in Dev Mode.
     */
    Active = 4,
}
/**
 * SyntheticEventFlags.
 */
export declare const enum SyntheticEventFlags {
    /**
     * Default behaviour should be prevented.
     */
    PreventedDefault = 1,
    /**
     * Propagation is stopped.
     */
    StoppedPropagation = 2,
    /**
     * Event can bubble up through the DOM.
     */
    Bubbles = 4,
    /**
     * Event is cancelable.
     */
    Cancelable = 8,
    /**
     * Event was initiated by the browser.
     */
    IsTrusted = 16,
    /**
     * Event at bubbling phase.
     */
    BubblePhase = 32,
}
export declare const enum EventFlags {
    PreventDefault = 1,
    StopPropagation = 2,
}
/**
 * Prevents default behaviour for an event.
 */
export declare const PREVENT_DEFAULT: SyntheticEventFlags;
/**
 * Stops event propagation.
 */
export declare const STOP_PROPAGATION: SyntheticEventFlags;
