import { NativeEventSourceFlags } from "./flags";
import { SyntheticNativeEvent } from "./synthetic_event";
import { EventSource } from "./event_source";
/**
 * NativeEventSource dispatches native events.
 *
 * It is using two-phase dispatching algorithm similar to native DOM events flow.
 */
export interface NativeEventSource<E extends Event> {
    /**
     * Public EventSource interface.
     */
    readonly src: EventSource;
    /**
     * Number of active dependencies.
     *
     * When there are active dependencies, event source will be activated by attaching native event listeners to the
     * document. When it goes to zero it will be deactivated, and all event listeners will be removed.
     */
    deps: number;
    /**
     * Number of active listeners.
     */
    listeners: number;
    /**
     * See `NativeEventSourceFlags` for details.
     */
    flags: NativeEventSourceFlags;
    /**
     * DOM event name.
     */
    readonly name: string;
    before: Array<(ev: SyntheticNativeEvent<E>) => void> | null;
    after: Array<(ev: SyntheticNativeEvent<E>) => void> | null;
    dispatch: (() => void) | null;
}
export declare function createNativeEventSource<E extends Event>(flags: NativeEventSourceFlags, name: string): NativeEventSource<E>;
export declare function addBeforeListener<E extends Event>(source: NativeEventSource<E>, cb: (e: SyntheticNativeEvent<E>) => void): void;
export declare function addAfterListener<E extends Event>(source: NativeEventSource<E>, cb: (e: SyntheticNativeEvent<E>) => void): void;
export declare function removeBeforeListener<E extends Event>(source: NativeEventSource<E>, cb: (e: SyntheticNativeEvent<E>) => void): void;
export declare function removeAfterListener<E extends Event>(source: NativeEventSource<E>, cb: (e: SyntheticNativeEvent<E>) => void): void;
