import { NativeEventSourceFlags } from "./flags";
import { EventHandler } from "./event_handler";
/**
 * Extends Element interface with a special property that is used to assign synthetic event handlers list.
 */
declare global  {
    interface Element {
        _ev: Array<EventHandler | null> | EventHandler | null | undefined;
    }
}
/**
 * getEventTarget retrieves target element from an event.
 *
 * There are still some differences in modern browsers, so we need to use this function to retrieve event targets.
 *
 * #quirks
 *
 * @param ev Event.
 * @returns Target Element.
 */
export declare function getEventTarget(ev: Event): EventTarget;
/**
 * `{ capture: true, passive: true }` object that should be used as a 3rd parameter for `addEventListener` method.
 */
export declare const EVENT_CAPTURE_PASSIVE_OPTIONS: boolean | {
    "capture": boolean;
    "passive": boolean;
};
/**
 * `{ capture: true, passive: false }` object that should be used as a 3rd parameter for `addEventListener` method.
 */
export declare const EVENT_CAPTURE_ACTIVE_OPTIONS: boolean | {
    "capture": boolean;
    "passive": boolean;
};
/**
 * `{ passive: true }` object that should be used as a 3rd parameter for `addEventListener` method.
 */
export declare const EVENT_PASSIVE_OPTIONS: boolean | {
    "passive": boolean;
};
/**
 * `{ passive: false }` object that should be used as a 3rd parameter for `addEventListener` method.
 */
export declare const EVENT_ACTIVE_OPTIONS: boolean | {
    "passive": boolean;
};
/**
 * getNativeEventOptions converts `NativeEventSourceFlags` to event options that can be used as a 3rd parameter
 * for `addEventListener` method.
 *
 * #quirks
 *
 * @param flags See `NativeEventSourceFlags` for details.
 * @returns Option object that can be used as a 3rd parameter for `addEventListener` method.
 */
export declare function getNativeEventOptions(flags: NativeEventSourceFlags): boolean | {
    capture?: boolean;
    passive?: boolean;
};
